==> open-xchange-util-custom_1.2.0.orig.tar.bz2: open-xchange-util-custom-1.2.0/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/MBeanRegistrar.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.util.activator.impl;

import static com.openexchange.util.custom.base.NullUtil.className;
import static com.openexchange.util.custom.base.NullUtil.logger;
import javax.annotation.Nullable;
import javax.annotation.ParametersAreNonnullByDefault;
import javax.management.ObjectName;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import org.slf4j.Logger;
import com.openexchange.management.ManagementService;

/**
 * {@link MBeanRegistrar}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v7.8.2
 */
@ParametersAreNonnullByDefault
public final class MBeanRegistrar<S, T extends S> implements ServiceTrackerCustomizer<ManagementService, ManagementService> {
    
    private static final Logger LOG = logger(MBeanRegistrar.class);
    
    private final BundleContext bundleContext;
    private final ActivatorRegistry registry;
    private final ObjectName objectName;
    private final Class<S> mbeanInterface;
    private final T mbean;

    public MBeanRegistrar(final BundleContext bundleContext,
        final ActivatorRegistry registry,
        final ObjectName objectName,
        final Class<S> mbeanInterface,
        final T mbean) {
        this.bundleContext = bundleContext;
        this.registry = registry;
        this.objectName = objectName;
        this.mbeanInterface = mbeanInterface;
        this.mbean = mbean;
    }

    @Override
    public ManagementService addingService(@Nullable ServiceReference<ManagementService> reference) {
        final ManagementService management = bundleContext.getService(reference);
        if (management != null) {
            try {
                management.registerMBean(objectName, mbean);
                registry.add(new MBeanRegistration(management, objectName, mbean));
            } catch (final Exception e) {
                LOG.warn(String.format("could not register MBean %s (%s) as '%s'",
                    className(mbean), mbeanInterface.getName(), objectName), e);
            } finally {
                bundleContext.ungetService(reference);
            }
            return management;
        } else {
            throw new IllegalStateException("ManagementService reference is null");
        }
    }

    @Override
    public void modifiedService(@Nullable ServiceReference<ManagementService> reference, @Nullable ManagementService management) {
        if (reference != null) {
            bundleContext.ungetService(reference);
        }
    }

    @Override
    public void removedService(@Nullable ServiceReference<ManagementService> reference, @Nullable ManagementService management) {
        if (reference != null) {
            bundleContext.ungetService(reference);
        }
    }
}

==> open-xchange-util-custom_1.3.3.orig.tar.bz2: open-xchange-util-custom-1.3.3/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/MBeanRegistrar.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.util.activator.impl;

import static com.openexchange.util.custom.base.NullUtil.className;
import static com.openexchange.util.custom.base.NullUtil.logger;


import javax.management.ObjectName;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import org.slf4j.Logger;
import com.openexchange.annotation.Nullable;
import com.openexchange.management.ManagementService;

/**
 * {@link MBeanRegistrar}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v7.8.2
 */
public final class MBeanRegistrar<S, T extends S> implements ServiceTrackerCustomizer<ManagementService, ManagementService> {
    
    private static final Logger LOG = logger(MBeanRegistrar.class);
    
    private final BundleContext bundleContext;
    private final ActivatorRegistry registry;
    private final ObjectName objectName;
    private final Class<S> mbeanInterface;
    private final T mbean;

    public MBeanRegistrar(final BundleContext bundleContext,
        final ActivatorRegistry registry,
        final ObjectName objectName,
        final Class<S> mbeanInterface,
        final T mbean) {
        this.bundleContext = bundleContext;
        this.registry = registry;
        this.objectName = objectName;
        this.mbeanInterface = mbeanInterface;
        this.mbean = mbean;
    }

    @Override
    public ManagementService addingService(@Nullable ServiceReference<ManagementService> reference) {
        final ManagementService management = bundleContext.getService(reference);
        if (management != null) {
            try {
                management.registerMBean(objectName, mbean);
                registry.add(new MBeanRegistration(management, objectName, mbean));
            } catch (final Exception e) {
                LOG.warn(String.format("could not register MBean %s (%s) as '%s'",
                    className(mbean), mbeanInterface.getName(), objectName), e);
            } finally {
                bundleContext.ungetService(reference);
            }
            return management;
        } else {
            throw new IllegalStateException("ManagementService reference is null");
        }
    }

    @Override
    public void modifiedService(@Nullable ServiceReference<ManagementService> reference, @Nullable ManagementService management) {
        if (reference != null) {
            bundleContext.ungetService(reference);
        }
    }

    @Override
    public void removedService(@Nullable ServiceReference<ManagementService> reference, @Nullable ManagementService management) {
        if (reference != null) {
            bundleContext.ungetService(reference);
        }
    }
}
